==> speech-analytic-testing_0.20.1_database.tar.gz: database/mssql/procedures/SaveVcc.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[SaveVcc] (
	@VCC Varchar(50) = NULL, 
	@ID Varchar(50) = NULL,
	@Description Varchar(50) = NULL,
	@Type VARCHAR(50) = NULL,
	@TranscriptionDefaultLanguage VARCHAR(25) = NULL,
	@CognitiveEngine VARCHAR(25) = NULL,
	@Country Varchar(50) = NULL,
	@Language Varchar(50) = NULL,
	@TimeZone Varchar(50) = NULL,
	@CreatedDate Datetime = NULL,
	@CreatedByUserId Varchar(50) = NULL,
	@LastModifiedDate Datetime = NULL,
	@LastModifiedByUserId Varchar(50) = NULL,
	@ChangedCognitiveEngine BIT = 0
	)
AS
BEGIN
	SET NOCOUNT ON
	DECLARE @IsMigrating BIT = 0
	IF(@ChangedCognitiveEngine IS NOT NULL AND @ChangedCognitiveEngine = 1)
	   SET @IsMigrating = 1
	   
	   
	UPDATE [VCC]
		SET [Description] = @Description,
			[Type] = @Type,
			[Country] = @Country,
			[TranscriptionDefaultLanguage] = @TranscriptionDefaultLanguage,
			[CognitiveEngine] = @CognitiveEngine,
			[Language] = @Language,
			[TimeZone] = @TimeZone,
			[CreatedDate] = CASE WHEN @CreatedDate IS NULL THEN [CreatedDate] ELSE @CreatedDate END,
			[CreatedByUserId] = CASE WHEN @CreatedByUserId IS NULL THEN [CreatedByUserId] ELSE @CreatedByUserId END,
			[LastModifiedDate] = CASE WHEN @LastModifiedDate IS NULL THEN [LastModifiedDate] ELSE @LastModifiedDate END,
			[LastModifiedByUserId] = CASE WHEN @LastModifiedByUserId IS NULL THEN [LastModifiedByUserId] ELSE @LastModifiedByUserId END,
			[IsMigrating] = IIF(@IsMigrating = 1,1,0),
			[TimeStamp] = GETUTCDATE()
		WHERE [VCC] = @VCC
			AND [ID] = @ID

    IF @@ROWCOUNT = 0
		INSERT INTO [VCC] (
			[VCC], [ID], [Description], [Type], [Country], 
			[TranscriptionDefaultLanguage], [CognitiveEngine], [Language], [TimeZone], [CreatedDate], 
			[CreatedByUserId], [LastModifiedDate], [LastModifiedByUserId], [TimeStamp]
			)
		VALUES (
			@VCC, @ID, @Description, @Type, @Country, 
			@TranscriptionDefaultLanguage, @CognitiveEngine, @Language, @TimeZone, @CreatedDate,  
			@CreatedByUserId, @LastModifiedDate, @LastModifiedByUserId, GETUTCDATE()
		)
		
	--SI HA CAMBIADO LOS NLUS ACTUALIZAR EL ESTADO DE LOS MODELOS A NO DISPONIBLE
	IF(@IsMigrating = 1)
	BEGIN 
	  EXEC SaveCognitiveEngineMigrateStatus @VCC,'*','*',0,'NOT_AVAILABLE'
	END
    SELECT 1 AS 'result'
    
    SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO

==> speech-analytic-testing_0.23.0_database.tar.gz: database/mssql/procedures/SaveVcc.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[SaveVcc] (
	@VCC Varchar(50) = NULL, 
	@ID Varchar(50) = NULL,
	@Description Varchar(50) = NULL,
	@Type VARCHAR(50) = NULL,
	@TranscriptionDefaultLanguage VARCHAR(25) = NULL,
	@CognitiveEngine VARCHAR(25) = NULL,
	@Country Varchar(50) = NULL,
	@Language Varchar(50) = NULL,
	@TimeZone Varchar(50) = NULL,
	@CreatedDate Datetime = NULL,
	@CreatedByUserId Varchar(50) = NULL,
	@LastModifiedDate Datetime = NULL,
	@LastModifiedByUserId   VARCHAR(50) = NULL,
	@DeleteDataDays         INT = 360,
	@ChangedCognitiveEngine BIT = 0
	)
AS
BEGIN
	SET NOCOUNT ON
	DECLARE @IsMigrating BIT = 0
	IF(@ChangedCognitiveEngine IS NOT NULL AND @ChangedCognitiveEngine = 1)
	   SET @IsMigrating = 1
	   
	   
	UPDATE [VCC]
		SET [Description] = @Description,
			[Type] = @Type,
			[Country] = @Country,
			[TranscriptionDefaultLanguage] = @TranscriptionDefaultLanguage,
			[CognitiveEngine] = @CognitiveEngine,
			[Language] = @Language,
			[TimeZone] = @TimeZone,
			[CreatedDate] = CASE WHEN @CreatedDate IS NULL THEN [CreatedDate] ELSE @CreatedDate END,
			[CreatedByUserId] = CASE WHEN @CreatedByUserId IS NULL THEN [CreatedByUserId] ELSE @CreatedByUserId END,
			[LastModifiedDate] = CASE WHEN @LastModifiedDate IS NULL THEN [LastModifiedDate] ELSE @LastModifiedDate END,
			[LastModifiedByUserId] = CASE WHEN @LastModifiedByUserId IS NULL THEN [LastModifiedByUserId] ELSE @LastModifiedByUserId END,
			[IsMigrating] = IIF(@IsMigrating = 1,1,0),
			[DeleteDataDays] = @DeleteDataDays,
			[TimeStamp] = GETUTCDATE()
		WHERE [VCC] = @VCC
			AND [ID] = @ID

    IF @@ROWCOUNT = 0
		INSERT INTO [VCC] (
			[VCC], [ID], [Description], [Type], [Country], 
			[TranscriptionDefaultLanguage], [CognitiveEngine], [Language], [TimeZone], [CreatedDate], 
			[CreatedByUserId], [LastModifiedDate], [LastModifiedByUserId], [DeleteDataDays], [TimeStamp]
			)
		VALUES (
			@VCC, @ID, @Description, @Type, @Country, 
			@TranscriptionDefaultLanguage, @CognitiveEngine, @Language, @TimeZone, @CreatedDate,  
			@CreatedByUserId, @LastModifiedDate, @LastModifiedByUserId, @DeleteDataDays, GETUTCDATE()
		)
		
	--SI HA CAMBIADO LOS NLUS ACTUALIZAR EL ESTADO DE LOS MODELOS A NO DISPONIBLE
	IF(@IsMigrating = 1)
	BEGIN 
	  EXEC SaveCognitiveEngineMigrateStatus @VCC,'*','*',0,'NOT_AVAILABLE'
	END
    SELECT 1 AS 'result'
    
    SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
